@@ -39,6 +39,7 @@ _CLIMATE_MASTER_PARAMETERS: Final[tuple[Parameter, ...]] = (
 
 _RELEVANT_MASTER_PARAMSETS_BY_DEVICE: Final[Mapping[str, tuple[tuple[int | None, ...], tuple[Parameter, ...]]]] = {
     "ALPHA-IP-RBG": ((1,), _CLIMATE_MASTER_PARAMETERS),
+    "ELV-SH-TACO": ((2,), (Parameter.CHANNEL_OPERATION_MODE,)),
     "HM-CC-RT-DN": (
         (None,),
         _CLIMATE_MASTER_PARAMETERS,
@@ -68,6 +69,7 @@ _RELEVANT_MASTER_PARAMSETS_BY_DEVICE: Final[Mapping[str, tuple[tuple[int | None,
     "HmIP-MOD-RC8": (tuple(range(1, 9)), (Parameter.CHANNEL_OPERATION_MODE,)),
     "HmIP-RGBW": ((0,), (Parameter.DEVICE_OPERATION_MODE,)),
     "HmIP-STH": ((1,), _CLIMATE_MASTER_PARAMETERS),
+    "HmIP-WGT": ((8, 14), _CLIMATE_MASTER_PARAMETERS),
     "HmIP-WTH": ((1,), _CLIMATE_MASTER_PARAMETERS),
     "HmIP-eTRV": ((1,), _CLIMATE_MASTER_PARAMETERS),
     "HmIPW-DRBL4": ((1, 5, 9, 13), (Parameter.CHANNEL_OPERATION_MODE,)),
@@ -264,6 +266,8 @@ _IGNORE_PARAMETERS_BY_DEVICE: Final[Mapping[Parameter, tuple[str, ...]]] = {
         "HmIP-PMFS",
         "HmIP-PS",
         "HmIP-SFD",
+        "HmIP-SMO230",
+        "HmIP-WGT",
     ),
     Parameter.VALVE_STATE: ("HmIPW-FALMOT-C12", "HmIP-FALMOT-C12"),
 }
@@ -280,6 +284,18 @@ _ACCEPT_PARAMETER_ONLY_ON_CHANNEL: Final[Mapping[str, int]] = {Parameter.LOWBAT:
 class ParameterVisibilityCache:
     """Cache for parameter visibility."""
 
+    __slots__ = (
+        "_central",
+        "_custom_un_ignore_complex",
+        "_custom_un_ignore_values_parameters",
+        "_ignore_custom_device_definition_models",
+        "_raw_un_ignores",
+        "_relevant_master_paramsets_by_device",
+        "_required_parameters",
+        "_storage_folder",
+        "_un_ignore_parameters_by_device_paramset_key",
+    )
+
     def __init__(
         self,
         central: hmcu.CentralUnit,
