@@ -9,7 +9,7 @@ from enum import Enum, IntEnum, StrEnum
 import re
 from typing import Any, Final, NamedTuple, Required, TypedDict
 
-VERSION: Final = "2025.7.0"
+VERSION: Final = "2025.8.0"
 
 # default
 DEFAULT_CUSTOM_ID: Final = "custom_id"
@@ -182,6 +182,7 @@ class DataPointCategory(StrEnum):
     SIREN = "siren"
     SWITCH = "switch"
     TEXT = "text"
+    UNDEFINED = "undefined"
     UPDATE = "update"
     VALVE = "valve"
 
@@ -352,6 +353,8 @@ class Parameter(StrEnum):
     MASS_CONCENTRATION_PM_1_24H_AVERAGE = "MASS_CONCENTRATION_PM_1_24H_AVERAGE"
     MASS_CONCENTRATION_PM_2_5_24H_AVERAGE = "MASS_CONCENTRATION_PM_2_5_24H_AVERAGE"
     MIN_MAX_VALUE_NOT_RELEVANT_FOR_MANU_MODE = "MIN_MAX_VALUE_NOT_RELEVANT_FOR_MANU_MODE"
+    MOTION = "MOTION"
+    MOTION_DETECTION_ACTIVE = "MOTION_DETECTION_ACTIVE"
     ON_TIME = "ON_TIME"
     OPEN = "OPEN"
     OPERATING_VOLTAGE = "OPERATING_VOLTAGE"
@@ -378,6 +381,7 @@ class Parameter(StrEnum):
     RAMP_TIME_TO_OFF_VALUE = "RAMP_TIME_TO_OFF_VALUE"
     RAMP_TIME_UNIT = "RAMP_TIME_UNIT"
     RAMP_TIME_VALUE = "RAMP_TIME_VALUE"
+    RESET_MOTION = "RESET_MOTION"
     RSSI_DEVICE = "RSSI_DEVICE"
     RSSI_PEER = "RSSI_PEER"
     SABOTAGE = "SABOTAGE"
