@@ -165,6 +165,14 @@ _SCHEDULE_DICT = dict[ScheduleProfile, PROFILE_DICT]
 class BaseCustomDpClimate(CustomDataPoint):
     """Base HomeMatic climate data_point."""
 
+    __slots__ = (
+        "_dp_humidity",
+        "_dp_min_max_value_not_relevant_for_manu_mode",
+        "_dp_setpoint",
+        "_dp_temperature",
+        "_dp_temperature_maximum",
+        "_dp_temperature_minimum",
+    )
     _category = DataPointCategory.CLIMATE
     _supports_schedule = False
 
@@ -660,10 +668,23 @@ class BaseCustomDpClimate(CustomDataPoint):
 class CustomDpSimpleRfThermostat(BaseCustomDpClimate):
     """Simple classic HomeMatic thermostat HM-CC-TC."""
 
+    __slots__ = ()
+
 
 class CustomDpRfThermostat(BaseCustomDpClimate):
     """Classic HomeMatic thermostat like HM-CC-RT-DN."""
 
+    __slots__ = (
+        "_dp_auto_mode",
+        "_dp_boost_mode",
+        "_dp_comfort_mode",
+        "_dp_control_mode",
+        "_dp_lowering_mode",
+        "_dp_manu_mode",
+        "_dp_temperature_offset",
+        "_dp_valve_state",
+        "_dp_week_program_pointer",
+    )
     _supports_schedule = True
 
     def _init_data_point_fields(self) -> None:
@@ -850,6 +871,19 @@ def _party_mode_code(start: datetime, end: datetime, away_temperature: float) ->
 class CustomDpIpThermostat(BaseCustomDpClimate):
     """HomematicIP thermostat like HmIP-eTRV-B."""
 
+    __slots__ = (
+        "_dp_active_profile",
+        "_dp_boost_mode",
+        "_dp_control_mode",
+        "_dp_heating_mode",
+        "_dp_heating_valve_type",
+        "_dp_level",
+        "_dp_optimum_start_stop",
+        "_dp_party_mode",
+        "_dp_set_point_mode",
+        "_dp_state",
+        "_dp_temperature_offset",
+    )
     _supports_schedule = True
 
     def _init_data_point_fields(self) -> None:
@@ -1079,8 +1113,8 @@ def _convert_time_str_to_minutes(time_str: str) -> int:
     try:
         h, m = time_str.split(":")
         return (int(h) * 60) + int(m)
-    except Exception as ex:
-        raise ValidationException(f"Failed to convert time {time_str}. Format must be hh:mm.") from ex
+    except Exception as exc:
+        raise ValidationException(f"Failed to convert time {time_str}. Format must be hh:mm.") from exc
 
 
 def _sort_simple_weekday_list(simple_weekday_list: SIMPLE_WEEKDAY_LIST) -> SIMPLE_WEEKDAY_LIST:
@@ -1223,6 +1257,7 @@ DEVICES: Mapping[str, CustomConfig | tuple[CustomConfig, ...]] = {
     "HmIP-HEATING": CustomConfig(make_ce_func=make_ip_thermostat_group),
     "HmIP-STH": CustomConfig(make_ce_func=make_ip_thermostat),
     "HmIP-WTH": CustomConfig(make_ce_func=make_ip_thermostat),
+    "HmIP-WGT": CustomConfig(make_ce_func=make_ip_thermostat, channels=(8,)),
     "HmIP-eTRV": CustomConfig(make_ce_func=make_ip_thermostat),
     "HmIPW-SCTHD": CustomConfig(make_ce_func=make_ip_thermostat),
     "HmIPW-STH": CustomConfig(make_ce_func=make_ip_thermostat),
