@@ -138,6 +138,14 @@ class LightOffArgs(TypedDict, total=False):
 class CustomDpDimmer(CustomDataPoint, TimerMixin):
     """Base class for HomeMatic light data point."""
 
+    __slots__ = (
+        "_dp_group_level",
+        "_dp_level",
+        "_dp_on_time_value",
+        "_dp_ramp_time_value",
+        "_timer_on_time",
+        "_timer_on_time_end",
+    )
     _category = DataPointCategory.LIGHT
 
     def _init_data_point_fields(self) -> None:
@@ -145,8 +153,8 @@ class CustomDpDimmer(CustomDataPoint, TimerMixin):
         TimerMixin.__init__(self)
         super()._init_data_point_fields()
         self._dp_level: DpFloat = self._get_data_point(field=Field.LEVEL, data_point_type=DpFloat)
-        self._dp_channel_level: DpSensor[float | None] = self._get_data_point(
-            field=Field.CHANNEL_LEVEL, data_point_type=DpSensor[float | None]
+        self._dp_group_level: DpSensor[float | None] = self._get_data_point(
+            field=Field.GROUP_LEVEL, data_point_type=DpSensor[float | None]
         )
         self._dp_on_time_value: DpAction = self._get_data_point(field=Field.ON_TIME_VALUE, data_point_type=DpAction)
         self._dp_ramp_time_value: DpAction = self._get_data_point(field=Field.RAMP_TIME_VALUE, data_point_type=DpAction)
@@ -167,17 +175,17 @@ class CustomDpDimmer(CustomDataPoint, TimerMixin):
         return int((self._dp_level.value or _MIN_BRIGHTNESS) * _LEVEL_TO_BRIGHTNESS_MULTIPLIER)
 
     @property
-    def channel_brightness(self) -> int | None:
-        """Return the channel_brightness of this light between min/max brightness."""
-        if self._dp_channel_level.value is not None:
-            return int(self._dp_channel_level.value * _MAX_BRIGHTNESS)
+    def group_brightness(self) -> int | None:
+        """Return the group brightness of this light between min/max brightness."""
+        if self._dp_group_level.value is not None:
+            return int(self._dp_group_level.value * _MAX_BRIGHTNESS)
         return None
 
     @property
-    def channel_brightness_pct(self) -> int | None:
-        """Return the channel_brightness in percent of this light."""
-        if self._dp_channel_level.value is not None:
-            return int(self._dp_channel_level.value * _LEVEL_TO_BRIGHTNESS_MULTIPLIER)
+    def group_brightness_pct(self) -> int | None:
+        """Return the group brightness in percent of this light."""
+        if self._dp_group_level.value is not None:
+            return int(self._dp_group_level.value * _LEVEL_TO_BRIGHTNESS_MULTIPLIER)
         return None
 
     @state_property
@@ -295,6 +303,8 @@ class CustomDpDimmer(CustomDataPoint, TimerMixin):
 class CustomDpColorDimmer(CustomDpDimmer):
     """Class for HomeMatic dimmer with color data point."""
 
+    __slots__ = ("_dp_color",)
+
     def _init_data_point_fields(self) -> None:
         """Init the data_point fields."""
         super()._init_data_point_fields()
@@ -331,6 +341,8 @@ class CustomDpColorDimmer(CustomDpDimmer):
 class CustomDpColorDimmerEffect(CustomDpColorDimmer):
     """Class for HomeMatic dimmer with color data point."""
 
+    __slots__ = ("_dp_effect",)
+
     _effects: tuple[str, ...] = (
         _EFFECT_OFF,
         "Slow color change",
@@ -380,6 +392,8 @@ class CustomDpColorDimmerEffect(CustomDpColorDimmer):
 class CustomDpColorTempDimmer(CustomDpDimmer):
     """Class for HomeMatic dimmer with color temperature."""
 
+    __slots__ = ("_dp_color_level",)
+
     def _init_data_point_fields(self) -> None:
         """Init the data_point fields."""
         super()._init_data_point_fields()
@@ -407,6 +421,19 @@ class CustomDpColorTempDimmer(CustomDpDimmer):
 class CustomDpIpRGBWLight(CustomDpDimmer):
     """Class for HomematicIP HmIP-RGBW light data point."""
 
+    __slots__ = (
+        "_dp_activity_state",
+        "_dp_color_temperature_kelvin",
+        "_dp_device_operation_mode",
+        "_dp_effect",
+        "_dp_hue",
+        "_dp_on_time_unit",
+        "_dp_ramp_time_to_off_unit",
+        "_dp_ramp_time_to_off_value",
+        "_dp_ramp_time_unit",
+        "_dp_saturation",
+    )
+
     def _init_data_point_fields(self) -> None:
         """Init the data_point fields."""
         super()._init_data_point_fields()
@@ -558,6 +585,17 @@ class CustomDpIpRGBWLight(CustomDpDimmer):
 class CustomDpIpDrgDaliLight(CustomDpDimmer):
     """Class for HomematicIP HmIP-DRG-DALI light data point."""
 
+    __slots__ = (
+        "_dp_color_temperature_kelvin",
+        "_dp_effect",
+        "_dp_hue",
+        "_dp_on_time_unit",
+        "_dp_ramp_time_to_off_unit",
+        "_dp_ramp_time_to_off_value",
+        "_dp_ramp_time_unit",
+        "_dp_saturation",
+    )
+
     def _init_data_point_fields(self) -> None:
         """Init the data_point fields."""
         super()._init_data_point_fields()
@@ -645,6 +683,15 @@ class CustomDpIpDrgDaliLight(CustomDpDimmer):
 class CustomDpIpFixedColorLight(CustomDpDimmer):
     """Class for HomematicIP HmIP-BSL light data point."""
 
+    __slots__ = (
+        "_dp_channel_color",
+        "_dp_color",
+        "_dp_effect",
+        "_dp_on_time_unit",
+        "_dp_ramp_time_unit",
+        "_effect_list",
+    )
+
     @state_property
     def color_name(self) -> str | None:
         """Return the name of the color."""
@@ -1038,6 +1085,7 @@ DEVICES: Mapping[str, CustomConfig | tuple[CustomConfig, ...]] = {
             }
         ),
     ),
+    "HmIP-WGT": CustomConfig(make_ce_func=make_ip_dimmer, channels=(2,)),
     "HmIPW-DRD3": CustomConfig(
         make_ce_func=make_ip_dimmer,
         channels=(2, 6, 10),
