@@ -6,7 +6,7 @@ from abc import ABC, abstractmethod
 from collections.abc import Callable, Mapping
 from contextvars import Token
 from datetime import datetime
-from functools import cached_property, partial, wraps
+from functools import partial, wraps
 from inspect import getfullargspec
 import logging
 from typing import Any, Final, cast
@@ -43,7 +43,7 @@ from hahomematic.context import IN_SERVICE_VAR
 from hahomematic.decorators import get_service_calls
 from hahomematic.exceptions import BaseHomematicException, HaHomematicException
 from hahomematic.model import device as hmd
-from hahomematic.model.decorators import config_property, state_property
+from hahomematic.model.decorators import cached_slot_property, config_property, state_property
 from hahomematic.model.support import (
     DataPointNameData,
     DataPointPathData,
@@ -53,7 +53,7 @@ from hahomematic.model.support import (
     convert_value,
     generate_unique_id,
 )
-from hahomematic.support import reduce_args
+from hahomematic.support import extract_exc_args
 
 __all__ = [
     "BaseDataPoint",
@@ -114,7 +114,23 @@ EVENT_DATA_SCHEMA = vol.Schema(
 class CallbackDataPoint(ABC):
     """Base class for callback data point."""
 
-    _category: DataPointCategory
+    __slots__ = (
+        "_cached_enabled_default",
+        "_cached_service_methods",
+        "_cached_service_method_names",
+        "_central",
+        "_custom_id",
+        "_data_point_updated_callbacks",
+        "_device_removed_callbacks",
+        "_modified_at",
+        "_path_data",
+        "_refreshed_at",
+        "_temporary_modified_at",
+        "_temporary_refreshed_at",
+        "_unique_id",
+    )
+
+    _category = DataPointCategory.UNDEFINED
 
     def __init__(self, central: hmcu.CentralUnit, unique_id: str) -> None:
         """Init the callback data_point."""
@@ -198,7 +214,7 @@ class CallbackDataPoint(ABC):
         """Return the data_point usage."""
         return DataPointUsage.DATA_POINT
 
-    @cached_property
+    @cached_slot_property
     def enabled_default(self) -> bool:
         """Return, if data_point should be enabled based on usage attribute."""
         return self.usage in (
@@ -224,12 +240,12 @@ class CallbackDataPoint(ABC):
         return self._path_data.state_path
 
     # @property
-    @cached_property
+    @cached_slot_property
     def service_methods(self) -> Mapping[str, Callable]:
         """Return all service methods."""
         return get_service_calls(obj=self)
 
-    @cached_property
+    @cached_slot_property
     def service_method_names(self) -> tuple[str, ...]:
         """Return all service methods."""
         return tuple(self.service_methods.keys())
@@ -254,8 +270,8 @@ class CallbackDataPoint(ABC):
 
     def _reset_temporary_timestamps(self) -> None:
         """Reset the temporary timestamps."""
-        self._set_temporary_modified_at(now=INIT_DATETIME)
-        self._set_temporary_refreshed_at(now=INIT_DATETIME)
+        self._set_temporary_modified_at(modified_at=INIT_DATETIME)
+        self._set_temporary_refreshed_at(refreshed_at=INIT_DATETIME)
 
     @abstractmethod
     def _get_path_data(self) -> PathData:
@@ -283,12 +299,14 @@ class CallbackDataPoint(ABC):
     @loop_check
     def fire_data_point_updated_callback(self, *args: Any, **kwargs: Any) -> None:
         """Do what is needed when the value of the data_point has been updated/refreshed."""
+        if not self._should_fire_data_point_updated_callback:
+            return
         for callback_handler in self._data_point_updated_callbacks:
             try:
                 kwargs[KWARGS_ARG_DATA_POINT] = self
                 callback_handler(*args, **kwargs)
-            except Exception as ex:
-                _LOGGER.warning("FIRE_DATA_POINT_UPDATED_EVENT failed: %s", reduce_args(args=ex.args))
+            except Exception as exc:
+                _LOGGER.warning("FIRE_DATA_POINT_UPDATED_EVENT failed: %s", extract_exc_args(exc=exc))
 
     @loop_check
     def fire_device_removed_callback(self, *args: Any) -> None:
@@ -296,26 +314,31 @@ class CallbackDataPoint(ABC):
         for callback_handler in self._device_removed_callbacks:
             try:
                 callback_handler(*args)
-            except Exception as ex:
-                _LOGGER.warning("FIRE_DEVICE_REMOVED_EVENT failed: %s", reduce_args(args=ex.args))
+            except Exception as exc:
+                _LOGGER.warning("FIRE_DEVICE_REMOVED_EVENT failed: %s", extract_exc_args(exc=exc))
 
-    def _set_modified_at(self, now: datetime = datetime.now()) -> None:
+    @property
+    def _should_fire_data_point_updated_callback(self) -> bool:
+        """Check if a data point has been updated or refreshed."""
+        return True
+
+    def _set_modified_at(self, modified_at: datetime) -> None:
         """Set modified_at to current datetime."""
-        self._modified_at = now
-        self._set_refreshed_at(now=now)
+        self._modified_at = modified_at
+        self._set_refreshed_at(refreshed_at=modified_at)
 
-    def _set_refreshed_at(self, now: datetime = datetime.now()) -> None:
+    def _set_refreshed_at(self, refreshed_at: datetime) -> None:
         """Set refreshed_at to current datetime."""
-        self._refreshed_at = now
+        self._refreshed_at = refreshed_at
 
-    def _set_temporary_modified_at(self, now: datetime = datetime.now()) -> None:
+    def _set_temporary_modified_at(self, modified_at: datetime) -> None:
         """Set temporary_modified_at to current datetime."""
-        self._temporary_modified_at = now
-        self._set_temporary_refreshed_at(now=now)
+        self._temporary_modified_at = modified_at
+        self._set_temporary_refreshed_at(refreshed_at=modified_at)
 
-    def _set_temporary_refreshed_at(self, now: datetime = datetime.now()) -> None:
+    def _set_temporary_refreshed_at(self, refreshed_at: datetime) -> None:
         """Set temporary_refreshed_at to current datetime."""
-        self._temporary_refreshed_at = now
+        self._temporary_refreshed_at = refreshed_at
 
     def __str__(self) -> str:
         """Provide some useful information."""
@@ -325,6 +348,17 @@ class CallbackDataPoint(ABC):
 class BaseDataPoint(CallbackDataPoint, PayloadMixin):
     """Base class for regular data point."""
 
+    __slots__ = (
+        "_cached_dpk",
+        "_cached_requires_polling",
+        "_channel",
+        "_client",
+        "_data_point_name_data",
+        "_device",
+        "_forced_usage",
+        "_is_in_multiple_channels",
+    )
+
     _ignore_multiple_channels_for_name: bool = False
 
     def __init__(
@@ -421,6 +455,31 @@ class BaseParameterDataPoint[
 ](BaseDataPoint):
     """Base class for stateless data point."""
 
+    __slots__ = (
+        "_cached__enabled_by_channel_operation_mode",
+        "_current_value",
+        "_default",
+        "_ignore_on_initial_load",
+        "_is_forced_sensor",
+        "_is_un_ignored",
+        "_max",
+        "_min",
+        "_multiplier",
+        "_operations",
+        "_parameter",
+        "_paramset_key",
+        "_previous_value",
+        "_raw_unit",
+        "_service",
+        "_special",
+        "_state_uncertain",
+        "_temporary_value",
+        "_type",
+        "_unit",
+        "_values",
+        "_visible",
+    )
+
     _unique_id_prefix: str = ""
 
     def __init__(
@@ -503,7 +562,7 @@ class BaseParameterDataPoint[
         """Return if the parameter is un ignored."""
         return self._is_un_ignored
 
-    @cached_property
+    @cached_slot_property
     def dpk(self) -> DataPointKey:
         """Return data_point key value."""
         return DataPointKey(
@@ -543,7 +602,7 @@ class BaseParameterDataPoint[
         """Return raw unit value."""
         return self._raw_unit
 
-    @cached_property
+    @cached_slot_property
     def requires_polling(self) -> bool:
         """Return whether the data_point requires polling."""
         return not self._channel.device.client.supports_push_updates or (
@@ -629,7 +688,7 @@ class BaseParameterDataPoint[
         """Return the if data_point is visible in ccu."""
         return self._visible
 
-    @cached_property
+    @cached_slot_property
     def _enabled_by_channel_operation_mode(self) -> bool | None:
         """Return, if the data_point/event must be enabled."""
         if self._channel.type_name not in _CONFIGURABLE_CHANNEL:
@@ -696,7 +755,7 @@ class BaseParameterDataPoint[
         return DEFAULT_MULTIPLIER
 
     @abstractmethod
-    async def event(self, value: Any) -> None:
+    async def event(self, value: Any, received_at: datetime = datetime.now()) -> None:
         """Handle event for which this handler has subscribed."""
 
     async def load_data_point_value(self, call_source: CallSource, direct_call: bool = False) -> None:
@@ -721,10 +780,11 @@ class BaseParameterDataPoint[
                 parameter=self._parameter,
                 call_source=call_source,
                 direct_call=direct_call,
-            )
+            ),
+            write_at=datetime.now(),
         )
 
-    def write_value(self, value: Any) -> tuple[ParameterT, ParameterT]:
+    def write_value(self, value: Any, write_at: datetime) -> tuple[ParameterT, ParameterT]:
         """Update value of the data_point."""
         self._reset_temporary_value()
 
@@ -737,24 +797,24 @@ class BaseParameterDataPoint[
 
         new_value = self._convert_value(value)
         if old_value == new_value:
-            self._set_refreshed_at()
+            self._set_refreshed_at(refreshed_at=write_at)
         else:
-            self._set_modified_at()
+            self._set_modified_at(modified_at=write_at)
             self._previous_value = old_value
             self._current_value = new_value
         self._state_uncertain = False
         self.fire_data_point_updated_callback()
         return (old_value, new_value)
 
-    def write_temporary_value(self, value: Any) -> None:
+    def write_temporary_value(self, value: Any, write_at: datetime) -> None:
         """Update the temporary value of the data_point."""
         self._reset_temporary_value()
 
         temp_value = self._convert_value(value)
         if self._value == temp_value:
-            self._set_temporary_refreshed_at()
+            self._set_temporary_refreshed_at(refreshed_at=write_at)
         else:
-            self._set_temporary_modified_at()
+            self._set_temporary_modified_at(modified_at=write_at)
             self._temporary_value = temp_value
             self._state_uncertain = True
         self.fire_data_point_updated_callback()
@@ -821,6 +881,12 @@ class BaseParameterDataPoint[
 class CallParameterCollector:
     """Create a Paramset based on given generic data point."""
 
+    __slots__ = (
+        "_central",
+        "_client",
+        "_paramsets",
+    )
+
     def __init__(self, client: hmcl.Client) -> None:
         """Init the generator."""
         self._client: Final = client
@@ -915,12 +981,12 @@ def bind_collector(
                 kwargs[_COLLECTOR_ARGUMENT_NAME] = collector
                 return_value = await func(*args, **kwargs)
                 await collector.send_data(wait_for_callback=wait_for_callback)
-            except BaseHomematicException as bhe:
+            except BaseHomematicException as bhexc:
                 if token:
                     IN_SERVICE_VAR.reset(token)
                 in_service = IN_SERVICE_VAR.get()
                 if not in_service and log_level > logging.NOTSET:
-                    logging.getLogger(args[0].__module__).log(level=log_level, msg=reduce_args(args=bhe.args))
+                    logging.getLogger(args[0].__module__).log(level=log_level, msg=extract_exc_args(exc=bhexc))
             else:
                 if token:
                     IN_SERVICE_VAR.reset(token)
